==> velocity_1.3.1.orig.tar.gz: velocity-1.3.1/src/java/org/apache/velocity/runtime/visitor/BaseVisitor.java <==
package org.apache.velocity.runtime.visitor;

/*
 * The Apache Software License, Version 1.1
 *
 * Copyright (c) 2000-2001 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution, if
 *    any, must include the following acknowlegement:
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowlegement may appear in the software itself,
 *    if and wherever such third-party acknowlegements normally appear.
 *
 * 4. The names "The Jakarta Project", "Velocity", and "Apache Software
 *    Foundation" must not be used to endorse or promote products derived
 *    from this software without prior written permission. For written
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache"
 *    nor may "Apache" appear in their names without prior written
 *    permission of the Apache Group.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */

import java.io.Writer;
import java.io.IOException;

import java.util.Map;

import org.apache.velocity.context.InternalContextAdapter;

import org.apache.velocity.runtime.parser.node.*;

/**
 * This is the base class for all visitors.
 * For each AST node, this class will provide
 * a bare-bones method for traversal.
 *
 * @author <a href="mailto:jvanzyl@apache.org">Jason van Zyl</a>
 * @author <a href="mailto:geirm@optonline.net">Geir Magnusson Jr.</a>
 * @version $Id: BaseVisitor.java,v 1.11 2001/10/22 03:53:26 jon Exp $
 */
public abstract class BaseVisitor implements ParserVisitor
{
    /** Context used during traversal */
    protected InternalContextAdapter context;
    
    /** Writer used as the output sink */
    protected Writer writer;
    
    public void setWriter( Writer writer )
    {
        this.writer = writer;
    }        

    public void setContext( InternalContextAdapter context)
    {
        this.context = context;
    }
    
    public Object visit(SimpleNode node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTprocess node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }

    public Object visit(ASTExpression node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }

    public Object visit(ASTAssignment node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTOrNode node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTAndNode node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }

    public Object visit(ASTEQNode node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTNENode node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }

    public Object visit(ASTLTNode node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }

    public Object visit(ASTGTNode node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTLENode node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTGENode node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTAddNode node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTSubtractNode node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTMulNode node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTDivNode node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTModNode node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTNotNode node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTNumberLiteral node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTStringLiteral node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTIdentifier node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTMethod node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTReference node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTTrue node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTFalse node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTBlock node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTText node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTIfStatement node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTElseStatement node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTElseIfStatement node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTComment node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }

    public Object visit(ASTObjectArray node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }

    public Object visit(ASTWord node, Object data)
    { 
        data = node.childrenAccept(this, data);   
        return data;
    }
    
    public Object visit(ASTSetDirective node, Object data)
    { 
        data = node.childrenAccept(this, data);   
        return data;
    }
    
    public Object visit(ASTDirective node, Object data)
    { 
        data = node.childrenAccept(this, data);   
        return data;
    }
}

==> velocity_1.4.orig.tar.gz: velocity-1.4/src/java/org/apache/velocity/runtime/visitor/BaseVisitor.java <==
package org.apache.velocity.runtime.visitor;

/*
 * Copyright 2000-2001,2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import java.io.Writer;

import org.apache.velocity.context.InternalContextAdapter;

import org.apache.velocity.runtime.parser.node.*;

/**
 * This is the base class for all visitors.
 * For each AST node, this class will provide
 * a bare-bones method for traversal.
 *
 * @author <a href="mailto:jvanzyl@apache.org">Jason van Zyl</a>
 * @author <a href="mailto:geirm@optonline.net">Geir Magnusson Jr.</a>
 * @version $Id: BaseVisitor.java,v 1.12.4.1 2004/03/03 23:23:02 geirm Exp $
 */
public abstract class BaseVisitor implements ParserVisitor
{
    /** Context used during traversal */
    protected InternalContextAdapter context;
    
    /** Writer used as the output sink */
    protected Writer writer;
    
    public void setWriter( Writer writer )
    {
        this.writer = writer;
    }        

    public void setContext( InternalContextAdapter context)
    {
        this.context = context;
    }
    
    public Object visit(SimpleNode node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTprocess node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }

    public Object visit(ASTExpression node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }

    public Object visit(ASTAssignment node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTOrNode node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTAndNode node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }

    public Object visit(ASTEQNode node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTNENode node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }

    public Object visit(ASTLTNode node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }

    public Object visit(ASTGTNode node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTLENode node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTGENode node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTAddNode node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTSubtractNode node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTMulNode node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTDivNode node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTModNode node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTNotNode node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTNumberLiteral node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTStringLiteral node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTIdentifier node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTMethod node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTReference node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTTrue node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTFalse node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTBlock node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTText node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTIfStatement node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTElseStatement node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTElseIfStatement node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }
    
    public Object visit(ASTComment node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }

    public Object visit(ASTObjectArray node, Object data)
    { 
        data = node.childrenAccept(this, data); 
        return data; 
    }

    public Object visit(ASTWord node, Object data)
    { 
        data = node.childrenAccept(this, data);   
        return data;
    }
    
    public Object visit(ASTSetDirective node, Object data)
    { 
        data = node.childrenAccept(this, data);   
        return data;
    }
    
    public Object visit(ASTDirective node, Object data)
    { 
        data = node.childrenAccept(this, data);   
        return data;
    }
}
